Index: /branches/eam_rel9_p0/psModules/src/objects/pmModelGroup.h
===================================================================
--- /branches/eam_rel9_p0/psModules/src/objects/pmModelGroup.h	(revision 5989)
+++ /branches/eam_rel9_p0/psModules/src/objects/pmModelGroup.h	(revision 5990)
@@ -9,6 +9,6 @@
  *  @author EAM, IfA
  *
- *  @version $Revision: 1.1.16.1 $ $Name: not supported by cvs2svn $
- *  @date $Date: 2006-01-10 04:46:03 $
+ *  @version $Revision: 1.1.16.2 $ $Name: not supported by cvs2svn $
+ *  @date $Date: 2006-01-15 18:20:41 $
  *
  *  Copyright 2004 Maui High Performance Computing Center, University of Hawaii
@@ -92,8 +92,8 @@
  * 
  *  This function constructs the PSF model for the given source based on the
- *  supplied psf and the FLT model for the object.
- * 
- */
-typedef bool (*pmModelFromPSFFunc)(pmModel *modelPSF, pmModel *modelFLT, pmPSF *psf);
+ *  supplied psf and the EXT model for the object.
+ * 
+ */
+typedef bool (*pmModelFromPSFFunc)(pmModel *modelPSF, pmModel *modelEXT, pmPSF *psf);
 
 /**
Index: /branches/eam_rel9_p0/psModules/src/objects/pmObjects.h
===================================================================
--- /branches/eam_rel9_p0/psModules/src/objects/pmObjects.h	(revision 5989)
+++ /branches/eam_rel9_p0/psModules/src/objects/pmObjects.h	(revision 5990)
@@ -10,6 +10,6 @@
  *  @author GLG, MHPCC
  *
- *  @version $Revision: 1.4.4.2 $ $Name: not supported by cvs2svn $
- *  @date $Date: 2006-01-14 07:00:25 $
+ *  @version $Revision: 1.4.4.3 $ $Name: not supported by cvs2svn $
+ *  @date $Date: 2006-01-15 18:21:19 $
  *
  *  Copyright 2004 Maui High Performance Computing Center, University of Hawaii
@@ -131,9 +131,9 @@
 /** pmModel data structure
  * 
  * Every source may have two types of models: a PSF model and a FLT (floating)
  * model. The PSF model represents the best fit of the image PSF to the specific
  * object. In this case, the PSF-dependent parameters are specified for the
  * object by the PSF, not by the fit. The FLT model represents the best fit of
  * the given model to the object, with all parameters floating in the fit.
  *  
  */
@@ -146,5 +146,5 @@
     int nDOF;    ///< number of degrees of freedom
     int nIter;    ///< number of iterations to reach min
-    int status;         ///< fit status
+    pmModelStatus status;  ///< fit status
     float radius;   ///< fit radius actually used
 }
@@ -166,5 +166,5 @@
     PM_SOURCE_SATURATED,                ///< random saturated pixels
     PM_SOURCE_STAR,                     ///< a good-quality star
-    PM_SOURCE_GALAXY,                   ///< an extended object (galaxy)
+    PM_SOURCE_EXTENDED,                 ///< an extended object (eg, galaxy)
 } pmSourceType;
 
@@ -172,5 +172,5 @@
     PM_SOURCE_DEFAULT    = 0x0000, ///<
     PM_SOURCE_PSFMODEL   = 0x0001, ///<
-    PM_SOURCE_FLTMODEL   = 0x0002, ///<
+    PM_SOURCE_EXTMODEL   = 0x0002, ///<
     PM_SOURCE_SUBTRACTED = 0x0004, ///<
     PM_SOURCE_FITTED     = 0x0008, ///<
@@ -200,5 +200,5 @@
     pmMoments *moments;   ///< Basic moments measure for the object.
     pmModel *modelPSF;   ///< PSF Model fit (parameters and type)
-    pmModel *modelFLT;   ///< FLT (floating) Model fit (parameters and type).
+    pmModel *modelEXT;   ///< EXT (floating) Model fit (parameters and type).
     pmSourceType type;   ///< Best identification of object.
     pmSourceMode mode;   ///< Best identification of object.
@@ -487,5 +487,5 @@
     pmSource *source,   ///< The input pmSource
     pmModel *model,   ///< model to be fitted
-    const bool PSF   ///< Treat model as PSF or FLT?
+    const bool PSF   ///< Treat model as PSF or EXT?
 );
 
@@ -569,4 +569,5 @@
  * This function converts the source classification into the closest available
  * approximation to the Dophot classification scheme:
+ * XXX EAM : fix this to use current source classification scheme
  * 
  * PM_SOURCE_DEFECT: 8
@@ -616,5 +617,5 @@
     pmSource *source,   ///< The input pmSource
     pmModel *model,   ///< model to be fitted
-    const bool PSF   ///< Treat model as PSF or FLT?
+    const bool PSF   ///< Treat model as PSF or EXT?
 );
 
@@ -632,5 +633,5 @@
     pmSource *source,   ///< The input pmSource
     pmModel *model,   ///< model to be fitted
-    const bool PSF   ///< Treat model as PSF or FLT?
+    const bool PSF   ///< Treat model as PSF or EXT?
 );
 
@@ -131,9 +131,9 @@
 /** pmModel data structure
  * 
- * Every source may have two types of models: a PSF model and a FLT (floating)
+ * Every source may have two types of models: a PSF model and a EXT (extended-source)
  * model. The PSF model represents the best fit of the image PSF to the specific
  * object. In this case, the PSF-dependent parameters are specified for the
@@ -131,9 +131,9 @@
  * model. The PSF model represents the best fit of the image PSF to the specific
  * object. In this case, the PSF-dependent parameters are specified for the
- * object by the PSF, not by the fit. The FLT model represents the best fit of
- * the given model to the object, with all parameters floating in the fit.
+ * object by the PSF, not by the fit. The EXT model represents the best fit of
+ * the given model to the object, with all shape parameters floating in the fit.
  *  
  */
